@@ -251,6 +251,22 @@ class R3sponse(object):
 
 
 	# a response object.
+	def serialize(self, response={}):
+		for key in list(response.keys()):
+			value = response[key]
+			if isinstance(value, dict):
+				value = self.serialize(value)
+			elif value in [True, "True", "true", "TRUE"]: value = True
+			elif value in [False, "False", "false", "FALSE"]: value = False
+			elif isinstance(value, str):
+				if "." in value:
+					try: value = float(value)
+					except: a=1
+				else:
+					try: value = int(value)
+					except: a=1
+			response[key] = value
+		return response
 	def response(self, response={
 			"success":False,
 			"message":None,
@@ -270,6 +286,7 @@ class R3sponse(object):
 			except: a=1
 			try:  del response["success"]
 			except: a=1
+			response = self.serializable(response)
 			return self.success_response(message, response)
 		else:
 			return self.error_response(response["error"])
